@@ -22,6 +22,7 @@ class BluexpressHandler:
                  user_cod=api_settings.BLUEXPRESS['USER_COD'],
                  account_client=api_settings.SENDER['ACCOUNT_CLIENT'],
                  base_url_rest=api_settings.BLUEXPRESS['BASE_URL_REST'],
+                 person_code=api_settings.SENDER['PERSON_CODE'],
                  verify=True, **kwargs):
 
         self.issue_wsdl = kwargs.pop('issue_wsdl', issue_wsdl)
@@ -29,6 +30,7 @@ class BluexpressHandler:
         self.user_cod = kwargs.pop('user_cod', user_cod)
         self.base_url_rest = kwargs.pop('base_url_rest', base_url_rest)
         self.account_client = kwargs.pop('account_client', account_client)
+        self.person_code = kwargs.pop('person_code', person_code)
         self.verify = kwargs.pop('verify', verify)
         self.header = self._headers(self.token_id, self.user_cod)
         self.connector = Connector(
@@ -117,7 +119,7 @@ class BluexpressHandler:
             'codigoMoneda': api_settings.BLUEXPRESS['CURRENCY_CODE'],
             'codigoEmpresa': api_settings.BLUEXPRESS['COMPANY_CODE'],
             'codigoTipoServicio': api_settings.BLUEXPRESS['SERVICE_TYPE_CODE'],
-            'codigoPersona': api_settings.SENDER['PERSON_CODE'],
+            'codigoPersona': self.person_code,
             'codigoFamiliaProducto': api_settings.BLUEXPRESS['PRODUCT_FAMILY_CODE'],
             'observaciones': '',
             'centroCosto': xsd.SkipValue,
